# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in LICENSE.txt

from util import *

class TempImage:
    """Stores data about a generated temporary image file.
    """

    def __init__(self, filename, filetype, settings, reffile, lossless = False):
        """Constructor.

        Creates the temporary file and measures it's properties.

        Data members:
        FileName       : File name of the generated image.
        FileType       : File type of the generated image (i.e. jpg, png or gif).
        TypeSettings   : Settings specific to file type with which the file
                         was generated. Stored as JPGSettings, PNGSettings or 
                         GIFSettings.
        Size           : Size of the generated image in bytes.
        PercentSizeRef : Size if % of size of reference file.
        Quality        : Quality of this file in %.
        """
        self.FileName = filename
        self.FileType = filetype
        self.TypeSettings = settings
        file_convert(filetype, settings, reffile.Name, self.FileName)
        refsize = reffile.Size
        self.Size = file_size(self.FileName)
        self.PercentSizeRef = float(self.Size) / float(refsize) * 100.0
        if lossless:
            self.Quality = 100.0
        else:
            self.Quality = file_quality(reffile.Name, self.FileName)

    def str_data(self, extended=False):
        output=str(self.Size) + " " + str(self.PercentSizeRef) + " " +\
               str(self.Quality) + " " + self.TypeSettings.str_data() 
        if extended:
            output=self.FileName + " " + self.FileType + " " + output
        return output

